@@ -1,10 +1,10 @@
 test_that("constant generates values equal to input argument", {
   for_all(
     a = any_vector(),
-    property = \(a) {
+    property = function(a) {
       for_all(
         b = constant(a),
-        property = \(b) expect_equal(a, b),
+        property = function(b) expect_equal(a, b),
         tests = nested_tests()
       )
     },
@@ -15,6 +15,6 @@ test_that("constant generates values equal to input argument", {
 test_that("constant can generate NULL values", {
   for_all(
     a = constant(NULL),
-    property = \(a) expect_equal(a, NULL)
+    property = function(a) expect_equal(a, NULL)
   )
 })
