@@ -22,7 +22,7 @@ test_suite_vector_generator(
 test_that("integer_ generates integers small enough to be squared", {
   for_all(
     a = integer_(),
-    property = \(a) is.integer(a * a) |> expect_true()
+    property = function(a) is.integer(a * a) %>% expect_true()
   )
 })
 
@@ -32,7 +32,7 @@ test_that("integer_bounded generates bounded integers", {
 
   for_all(
     a = integer_bounded(left = left, right = right),
-    property = \(a) all(a >= left & a <= right) |> expect_true()
+    property = function(a) all(a >= left & a <= right) %>% expect_true()
   )
 })
 
@@ -41,7 +41,7 @@ test_that("integer_left_bounded generates left bounded integers", {
 
   for_all(
     a = integer_left_bounded(left = left),
-    property = \(a) all(a >= left) |> expect_true()
+    property = function(a) all(a >= left) %>% expect_true()
   )
 })
 
@@ -50,21 +50,21 @@ test_that("integer_right_bounded generates right bounded integers", {
 
   for_all(
     a = integer_right_bounded(right = right),
-    property = \(a) all(a <= right) |> expect_true()
+    property = function(a) all(a <= right) %>% expect_true()
   )
 })
 
 test_that("integer_positive generates positive integers", {
   for_all(
     a = integer_positive(),
-    property = \(a) all(a > 0L) |> expect_true()
+    property = function(a) all(a > 0L) %>% expect_true()
   )
 })
 
 test_that("integer_negative generates negative integers", {
   for_all(
     a = integer_negative(),
-    property = \(a) all(a < 0L) |> expect_true()
+    property = function(a) all(a < 0L) %>% expect_true()
   )
 })
 
@@ -82,5 +82,5 @@ test_that("max_positive_integer can be squared when big_int = FALSE", {
   max_int <-
     max_positive_integer(big_int = FALSE)
 
-  is.integer(max_int * max_int) |> expect_true()
+  is.integer(max_int * max_int) %>% expect_true()
 })
