@@ -1,10 +1,10 @@
 test_that("list_ wraps a single generator in a list", {
   for_all(
     a = anything(),
-    property = \(a) {
+    property = function(a) {
       for_all(
         b = list_(constant(a)),
-        property = \(b) list(a) |> expect_equal(b),
+        property = function(b) list(a) %>% expect_equal(b),
         tests = nested_tests()
       )
     },
@@ -15,14 +15,14 @@ test_that("list_ wraps a single generator in a list", {
 test_that("list_ wraps multiple generators in a list", {
   for_all(
     a = list_(any_atomic(), any_atomic()),
-    property = \(a)
-      is.list(a) && is.atomic(a[[1]]) && is.atomic(a[[2]]) |> expect_true()
+    property = function(a)
+      is.list(a) && is.atomic(a[[1]]) && is.atomic(a[[2]]) %>% expect_true()
   )
 })
 
 test_that("list_ maintains names", {
   for_all(
     a = list_(x = anything(), y = anything()),
-    property = \(a) names(a) |> expect_equal(c("x", "y"))
+    property = function(a) names(a) %>% expect_equal(c("x", "y"))
   )
 })
