@@ -1,10 +1,10 @@
 test_that("one_of doesn't modify a single generator", {
   for_all(
     a = anything(),
-    property = \(a) {
+    property = function(a) {
       for_all(
         b = one_of(constant(a)),
-        property = \(b) expect_equal(a, b),
+        property = function(b) expect_equal(a, b),
         tests = nested_tests()
       )
     },
@@ -19,7 +19,7 @@ test_that("one_of can ignore the first generator", {
       integer_negative(),
       prob = c(0, 1)
     ),
-    property = \(a) all(a < 0L) |> expect_true()
+    property = function(a) all(a < 0L) %>% expect_true()
   )
 })
 
@@ -30,6 +30,6 @@ test_that("one_of can ignore the second generator", {
       integer_negative(),
       prob = c(1, 0)
     ),
-    property = \(a) all(a > 0L) |> expect_true()
+    property = function(a) all(a > 0L) %>% expect_true()
   )
 })
